#[non_exhaustive]pub enum CacheReadStrategy {
WritesOnly,
BranchReads,
All,
}Expand description
The strategy for caching nodes that are read from the storage layer. Generally, we only want to cache write operations, but for some read-heavy workloads you can enable caching of branch reads or all reads.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WritesOnly
Only cache writes (no reads will be cached)
BranchReads
Cache branch reads (reads that are not leaf nodes)
All
Cache all reads (leaves and branches)