NodeStoreHeader

Struct NodeStoreHeader 

pub struct NodeStoreHeader { /* private fields */ }
Persisted metadata for a NodeStore. The NodeStoreHeader is at the start of the ReadableStorage.

root_hash, cargo_version and git_describe were added between v0.0.18 and v0.1.0. If version is not equal to firewood-v1, this field may contain “uninitialized” data and must be ignored. Uninitialized data in this context means whatever the filesystem returns when reading from the sparse region of the file where there previously was no data written. This does not mean uninitialized memory with respect to memory safety, but does mean that the data may be garbage.

Implementations

Source

impl NodeStoreHeader

pub const SIZE: u64 = 2048

The first SIZE bytes of the ReadableStorage are reserved for the NodeStoreHeader. We also want it aligned to a disk block

pub fn read_from_storage<S: ReadableStorage>( storage: &S, ) -> Result<Self, FileIoError>

Reads the NodeStoreHeader from the start of the given storage.

Errors

Returns an error if unable to read the header from storage or if there’s a node hash algorithm mismatch.

pub fn new(node_hash_algorithm: NodeHashAlgorithm) -> Self

Creates a new header with default values and no root address.

pub fn validate( &self, expected_node_hash_algorithm: NodeHashAlgorithm, ) -> Result<(), Error>

Validates the header fields to ensure correctness and compatibility with the current build of firewood.

Checks performed:

  • Magic number / version string is valid. The first 16 bytes must match an expected magic number.
  • Endianness test matches expected value (1). If not, reading from the database will produce incorrect results from mis-interpreted byte order.
  • Area size hash matches the expected hash for the current build. This prevents corrupting the allocation structures by changing area sizes.
  • Node hash algorithm flag matches the expected algorithm for this storage.
Errors

Returns an error if validation fails.

pub const fn size(&self) -> u64

Get the size of the nodestore

pub const fn set_size(&mut self, size: u64)

Set the size of the nodestore

pub const fn free_lists(&self) -> &[Option<LinearAddress>; 23]

Get the free lists

pub const fn free_lists_mut(&mut self) -> &mut [Option<LinearAddress>; 23]

Get mutable access to the free lists

pub const fn root_address(&self) -> Option<LinearAddress>

Get the root address

pub fn set_root_location( &mut self, root_location: Option<(LinearAddress, TrieHash)>, )

Update the root location, both address and hash.

Note that this does not overwrite the version field, so it is possible the root hash will be ignored when set.

pub const fn free_lists_offset() -> u64

Get the offset of the free_lists field for use with offset_of!

pub const fn cargo_version(&self) -> Option<&CargoVersion>

Get the cargo version of firewood-storage used to create this database, if available.

pub const fn git_describe(&self) -> Option<&GitDescribe>

Get the git describe string of firewood used to create this database,

Source

impl NodeStoreHeader

pub fn flush_to<S: WritableStorage>( &self, storage: &S, ) -> Result<(), FileIoError>

Persist this header to storage.

Errors

Returns a FileIoError if the header cannot be written.