pub struct PathComponent(pub U4);Expand description
A path component in a hexary trie; which is only 4 bits (aka a nibble).
Tuple Fields
0: U4Implementations
Sourceimpl PathComponent
impl PathComponent
Sourcepub const ALL: [Self; 16]
pub const ALL: [Self; 16]
All possible path components.
This makes it easy to iterate over all possible children of a branch in a type-safe way. It is preferrable to do:
ⓘ
for (idx, slot) in PathComponent::ALL.into_iter().zip(branch.children.each_ref()) {
/// use idx and slot
}instead of using a raw range like (0..16) or Iterator::enumerate,
which does not give a type-safe path component.
Sourceimpl PathComponent
impl PathComponent
Sourcepub const fn new_pair(v: u8) -> (Self, Self)
pub const fn new_pair(v: u8) -> (Self, Self)
Creates a pair of path components from a single byte where the upper 4 bits are the first component and the lower 4 bits are the second component.
Sourcepub const fn join(self, other: Self) -> u8
pub const fn join(self, other: Self) -> u8
Joins this PathComponent with another to create a single u8 where
this component is the upper 4 bits and the provided component is the
lower 4 bits.