pub enum NodeHashAlgorithm {
MerkleDB,
Ethereum,
}Expand description
The hash algorithm used by the node store.
This must currently match the compile-time option. However, it will eventually be made a runtime option when initializing the node store. Therefore, the option is required when initializing and opening the node store to ensure compatibility and to detect any mismatches.
Variants
MerkleDB
Use the MerkleDB node hashing algorithm, with sha256 as the hash function.
Ethereum
Use the Ethereum state trie node hashing algorithm, with keccak256 as the hash function.
Implementations
Sourceimpl NodeHashAlgorithm
impl NodeHashAlgorithm
Sourcepub const fn matches_compile_option(self) -> bool
pub const fn matches_compile_option(self) -> bool
Returns whether this hash algorithm matches the compile-time option.