PathComponent

Struct PathComponent 

pub struct PathComponent(pub U4);
A path component in a hexary trie; which is only 4 bits (aka a nibble).

Tuple Fields

0: U4

Implementations

Source

impl PathComponent

pub const ALL: [Self; 16]

All possible path components.

This makes it easy to iterate over all possible children of a branch in a type-safe way. It is preferrable to do:

for (idx, slot) in PathComponent::ALL.into_iter().zip(branch.children.each_ref()) {
    /// use idx and slot
}

instead of using a raw range like (0..16) or Iterator::enumerate, which does not give a type-safe path component.

pub const LEN: usize = 16

The number of possible path components.

Source

impl PathComponent

pub const fn as_u8(self) -> u8

Returns the path component as a u8.

pub const fn as_usize(self) -> usize

Returns the path component as a usize.

pub const fn try_new(value: u8) -> Option<Self>

Tries to create a path component from the given u8.

For hexary tries, the input must be in the range 0x00 to 0x0F inclusive. Any value outside this range will result in None.

For 256-ary tries, any value is valid.

pub const fn new_pair(v: u8) -> (Self, Self)

Creates a pair of path components from a single byte where the upper 4 bits are the first component and the lower 4 bits are the second component.

pub const fn join(self, other: Self) -> u8

Joins this PathComponent with another to create a single u8 where this component is the upper 4 bits and the provided component is the lower 4 bits.